Ryser - Latin Squares and Related Designs — Ryser 0.0.10 documentation

### Navigation

- index
- modules |
- next |
- Ryser 0.0.10 documentation »

# Ryser - Latin Squares and Related Designs

Ryser is a Python library for modelling latin squares and related designs. In Ryser you will find components for building partial combinatorial structures as well as algorithmic components for investigating the completability of particular instances of such structures.

This is the homepage and documentation index for Ryser. Here you will find all links to source code, documentation and downloads. The documentation index follows below.

- Homepage: http://pythonhosted.org/ryser/
- Documentation: http://pythonhosted.org/ryser/#documentation
- Download: https://pypi.python.org/pypi/ryser/
- Source Code Repository: https://bitbucket.org/matthew/ryser

## Documentation

- Introduction
- Installation
  - Requirements
  - Download
  - Installation Instructions
- Tutorial
  - Example: Completing Partial Latin Squares
  - Example: Hall Numbers
- Modules
  - Designs
  - Graphs
  - Hall
  - Output
  - Utils

### Navigation

- index
- modules |
- next |
- Ryser 0.0.10 documentation »